@@ -58,7 +58,7 @@ except ImportError:
 else:
     HAVE_DOCUTILS = True
 
-VERSION = "0.9.3"
+VERSION = "0.9.4"
 
 class Config:
     """
@@ -89,7 +89,10 @@ class Config:
                     'font_family' : 'Courier', # monospaced on all platforms
                     'font_size' : '10',
                     'list_font_family' : 'Helvetica', # sans on all platforms
+                    'list_font_family_fixed' : 'Courier', # monospace on all platforms
                     'list_font_size' : '10',
+                    'layout' : 'horizontal',
+                    'print_columns' : '0',
                     'background_color' : 'white',
                     'sn_username' : '',
                     'sn_password' : '',
@@ -140,8 +143,12 @@ class Config:
         self.font_size = cp.getint(cfg_sec, 'font_size')
 
         self.list_font_family = cp.get(cfg_sec, 'list_font_family')
+        self.list_font_family_fixed = cp.get(cfg_sec, 'list_font_family_fixed')
         self.list_font_size = cp.getint(cfg_sec, 'list_font_size')
 
+        self.layout = cp.get(cfg_sec, 'layout')
+        self.print_columns = cp.getint(cfg_sec, 'print_columns')
+
         self.background_color = cp.get(cfg_sec, 'background_color')
 
         self.rest_css_path = cp.get(cfg_sec, 'rest_css_path')
@@ -272,10 +279,11 @@ class Controller:
         self.view.add_observer('change:search_mode', self.observer_view_change_search_mode)
 
         # nn is a list of (key, note) objects
-        nn, match_regexp = self.notes_db.filter_notes()
+        nn, match_regexp, active_notes = self.notes_db.filter_notes()
         # this will trigger the list_change event
         self.notes_list_model.set_list(nn)
         self.notes_list_model.match_regexp = match_regexp
+        self.view.set_note_tally(len(nn), active_notes, len(self.notes_db.notes))
 
         # we'll use this to keep track of the currently selected note
         # we only use idx, because key could change from right under us.
@@ -522,9 +530,10 @@ class Controller:
         k = self.get_selected_note_key()
         # for each new evt.value coming in, get a new list from the notes_db
         # and set it in the notes_list_model
-        nn, match_regexp = self.notes_db.filter_notes(evt.value)
+        nn, match_regexp, active_notes = self.notes_db.filter_notes(evt.value)
         self.notes_list_model.set_list(nn)
         self.notes_list_model.match_regexp = match_regexp
+        self.view.set_note_tally(len(nn), active_notes, len(self.notes_db.notes))
 
         idx = self.notes_list_model.get_idx(k)
 
@@ -624,14 +633,31 @@ class Controller:
         self.view.select_note(idx)
 
     def select_note(self, idx):
+        """Called whenever user selects a different note via the UI.
+
+        This sets all machinery in motion to put the now note's data in all
+        the right places.
+
+        @param idx:
+        @return:
+        """
+
         if idx >= 0:
             key = self.notes_list_model.list[idx].key
             note = self.notes_db.get_note(key)
+            # valid note, so note editing should be enabled
+            self.view.set_note_editing(True)
 
         else:
             key = None
             note = None
             idx = -1
+            # no note selected, so we clear the UI (and display a clear
+            # message that no note is selected) and we disable note
+            # editing controls.
+            self.view.clear_note_ui()
+            self.view.set_note_editing(False)
+
 
         self.selected_note_idx = idx
 
