@@ -141,22 +141,49 @@ class StatusBar(tk.Frame):
     # global status
     # note status
 
+    # http://colorbrewer2.org/index.php?type=sequential&scheme=OrRd&n=3
+    # from light to dark orange; colorblind-safe scheme
+    #NOTE_STATUS_COLORS = ["#FEE8C8", "#FDBB84", "#E34A33"]
+
+    # http://colorbrewer2.org/index.php?type=diverging&scheme=RdYlBu&n=5
+    # diverging red to blue; colorblind-safe scheme
+    # red, lighter red, light yellow, light blue, dark blue
+    NOTE_STATUS_COLORS = ["#D7191C", "#FDAE61", "#FFFFBF", "#ABD9E9", "#2C7BB6"]
+    # 0 - saved and synced - light blue - 3
+    # 1 - saved - light yellow - 2
+    # 2 - modified - lighter red - 1
+    NOTE_STATUS_LUT = {0 : 3, 1 : 2, 2 : 1}
+
     def __init__(self, master):
         tk.Frame.__init__(self, master)
-        
-        self.status = tk.Label(self, relief=tk.SUNKEN, anchor=tk.W)
-        #self.label.pack(fill=tk.X)
+
+        self.status = tk.Label(self, relief=tk.SUNKEN, anchor=tk.W, width=40)
         self.status.pack(side=tk.LEFT, fill=tk.X, expand=1)
-        
-        self.note_status = tk.Label(self, relief=tk.SUNKEN, anchor=tk.W)
+
+        self.centre_status = tk.Label(self, relief=tk.SUNKEN, anchor=tk.W, width=35)
+        self.centre_status.pack(side=tk.LEFT, fill=tk.X, padx=5)
+
+        self.note_status = tk.Label(self, relief=tk.SUNKEN, anchor=tk.W, width=25)
         self.note_status.pack(side=tk.LEFT, fill=tk.X)
-        
+
+    def set_centre_status(self, fmt, *args):
+        self.centre_status.config(text=fmt % args)
+        self.centre_status.update_idletasks()
+
     def set_note_status(self, fmt, *args):
         """ *.. .s. .sS
         """ 
         self.note_status.config(text=fmt % args)
         self.note_status.update_idletasks()
 
+    def set_note_status_color(self, status_idx):
+        """
+        @param status_idx: 0 - saved and synced; 1 - saved; 2 - modified
+        """
+
+        color_idx = self.NOTE_STATUS_LUT[status_idx]
+        self.note_status.config(background=self.NOTE_STATUS_COLORS[color_idx])
+
     def set_status(self, fmt, *args):
         self.status.config(text=fmt % args)
         self.status.update_idletasks()
@@ -176,7 +203,7 @@ class NotesList(tk.Frame):
     MODIFYDATE_COL = 2
     PINNED_COL = 3
 
-    def __init__(self, master, font_family, font_size, background_color):
+    def __init__(self, master, font_family, font_size, config):
         tk.Frame.__init__(self, master)
 
         yscrollbar = tk.Scrollbar(self)
@@ -191,7 +218,7 @@ class NotesList(tk.Frame):
             font=f,
             yscrollcommand=yscrollbar.set,
             undo=True,
-            background = background_color)
+            background = config.background_color)
         # change default font at runtime with:
         #text.config(font=f)
 
@@ -227,6 +254,12 @@ class NotesList(tk.Frame):
         # list containing tuples with each note's title, tags,
         self.note_headers = []
 
+        self.layout=config.layout
+        self.print_columns=config.print_columns
+        if bold_font.measure(' ') > f.measure(' '):
+            self.cwidth = bold_font.measure(' ')
+        else:
+            self.cwidth = f.measure(' ')
         self.fonts = [f, italic_font, bold_font]
 
     def append(self, note, config):
@@ -234,7 +267,6 @@ class NotesList(tk.Frame):
         @param note: The complete note dictionary.
         """
 
-
         title = utils.get_note_title(note)
         tags = note.get('tags')
         modifydate = float(note.get('modifydate'))
@@ -243,26 +275,44 @@ class NotesList(tk.Frame):
 
         self.enable_text()
 
+        if self.layout == "vertical" and self.print_columns == 1:
+            nrchars, rem = divmod((self.text.winfo_width()), self.cwidth)
+            cellwidth = (int(nrchars) - 8)/2
+            
+            if pinned:
+                title += ' *'
 
-        self.text.insert(tk.END, title, ("title,"))
+            self.text.insert(tk.END, '{0:<{w}}'.format(title[:cellwidth-1], w=cellwidth), ("title,"))
 
-        if pinned:
-            self.text.insert(tk.END, ' *', ("pinned",))
+            if tags > 0:
+                if config.tagfound:
+                    self.text.insert(tk.END, '{0:<{w}}'.format(','.join(tags)[:cellwidth-1], w=cellwidth), ("found",))
+                else:
+                    self.text.insert(tk.END, '{0:<{w}}'.format(','.join(tags)[:cellwidth-1], w=cellwidth), ("tags",))
 
-        self.text.insert(tk.END, ' ' + utils.human_date(modifydate), ("modifydate",))
+            self.text.insert(tk.END, ' ' + utils.human_date(modifydate), ("modifydate",))
 
-        # tags can be None (newly created note) or [] or ['tag1', 'tag2']
-        if tags > 0:
-            if config.tagfound:
-                self.text.insert(tk.END, ' ' + ','.join(tags), ("found",))
-            else:
-                self.text.insert(tk.END, ' ' + ','.join(tags), ("tags",))
+            # tags can be None (newly created note) or [] or ['tag1', 'tag2']
+        else:
+            self.text.insert(tk.END, title, ("title,"))
 
+            if pinned:
+                self.text.insert(tk.END, ' *', ("pinned",))
+
+            self.text.insert(tk.END, ' ' + utils.human_date(modifydate), ("modifydate",))
+
+            # tags can be None (newly created note) or [] or ['tag1', 'tag2']
+            if tags > 0:
+                if config.tagfound:
+                    self.text.insert(tk.END, ' ' + ','.join(tags), ("found",))
+                else:
+                    self.text.insert(tk.END, ' ' + ','.join(tags), ("tags",))
 
         self.text.insert(tk.END, '\n')
 
         self.disable_text()
 
+
     def _bind_events(self):
         # Text widget events ##########################################
 
@@ -538,6 +588,10 @@ class View(utils.SubjectMixin):
 
         self._create_ui()
         self._bind_events()
+
+        # set default font for dialog boxes on Linux
+        # on Windows, tkinter uses system dialogs in any case
+        self.root.option_add('*Dialog.msg.font', 'Helvetica 12')
         
         self.text_tags_links = []
         self.text_tags_search = []
@@ -569,6 +623,21 @@ class View(utils.SubjectMixin):
         # we don't want the text bind_class() handler for Ctrl-A to be fired.
         return "break"
 
+    def set_note_editing(self, enable=True):
+        """Enable or disable note editing controls.
+
+        This is used to disable the controls when no note has been selected.
+        Disables note text widget, tag entry and pinned checkbutton.
+
+        @param enable: enable controls if True, else disable.
+        @return: Nothing.
+        """
+
+        state = tk.NORMAL if enable else tk.DISABLED
+        self.text_note.config(state=state)
+        self.tags_entry.config(state=state)
+        self.pinned_checkbutton.config(state=state)
+
     def get_continuous_rendering(self):
         return self.continuous_rendering.get()
 
@@ -638,14 +707,21 @@ class View(utils.SubjectMixin):
         
         if status.modified:
             s = 'modified'
+            self.statusbar.set_note_status_color(2)
         elif status.saved and status.synced:
-            s = 'saved and synced'
+            s = 'saved + synced'
+            self.statusbar.set_note_status_color(0)
         elif status.saved:
             s = 'saved'
+            self.statusbar.set_note_status_color(1)
         else:
             s = 'synced'
+            self.statusbar.set_note_status_color(0)
         
-        self.statusbar.set_note_status('Note is %s' % (s,))
+        self.statusbar.set_note_status('Current note %s' % (s,))
+
+    def set_note_tally(self, filtered_notes, active_notes, total_notes):
+        self.statusbar.set_centre_status('Listing %d / %d active notes (%d total)' % (filtered_notes, active_notes, total_notes))
             
     def set_search_entry_text(self, text):
         self.search_entry_var.set(text)
@@ -845,7 +921,7 @@ class View(utils.SubjectMixin):
         # during sash moving and resizing
         self.statusbar = StatusBar(self.root)
         self.statusbar.set_status('%s', 'Welcome to nvPY!')
-        self.statusbar.pack(fill=tk.X, side=tk.BOTTOM)
+        self.statusbar.pack(fill=tk.X, side=tk.BOTTOM, padx=3, pady=3)
 
         search_frame = tk.Frame(self.root)
         
@@ -877,28 +953,60 @@ class View(utils.SubjectMixin):
         
         
         # the paned window ##############################################
-        paned_window = tk.PanedWindow(self.root, orient=tk.HORIZONTAL)
-        paned_window.pack(fill=tk.BOTH, expand=1)
         
-        left_frame = tk.Frame(paned_window, width=100)
-        paned_window.add(left_frame)
+        if self.config.layout == "horizontal":
+            paned_window = tk.PanedWindow(self.root, orient=tk.HORIZONTAL)
+            paned_window.pack(fill=tk.BOTH, expand=1)
+            
+            list_frame = tk.Frame(paned_window, width=100)
+            paned_window.add(list_frame)
 
-        self.notes_list = NotesList(
-            left_frame,
-            self.config.list_font_family, self.config.list_font_size, self.config.background_color)
-        self.notes_list.pack(fill=tk.BOTH, expand=1)
+            self.notes_list = NotesList(
+                list_frame,
+                self.config.list_font_family,
+                self.config.list_font_size,
+                utils.KeyValueObject(background_color=self.config.background_color,
+                    layout=self.config.layout,
+                    print_columns=self.config.print_columns))
+            self.notes_list.pack(fill=tk.BOTH, expand=1)
 
-        right_frame = tk.Frame(paned_window, width=400)
-        paned_window.add(right_frame)
+            note_frame = tk.Frame(paned_window, width=400)
 
-        note_meta_frame = tk.Frame(right_frame)
+        else:
+            paned_window = tk.PanedWindow(self.root, orient=tk.VERTICAL)
+            paned_window.pack(fill=tk.BOTH, expand=1)
+            
+            list_frame = tk.Frame(paned_window, height=150)
+            list_frame.pack_propagate(0)
+            paned_window.add(list_frame)
+
+            if self.config.print_columns == 1:
+                font_family=self.config.list_font_family_fixed
+
+            else:
+                font_family=self.config.list_font_family
+
+            self.notes_list = NotesList(
+                list_frame,
+                font_family,
+                self.config.list_font_size,
+                utils.KeyValueObject(background_color=self.config.background_color,
+                    layout=self.config.layout,
+                    print_columns=self.config.print_columns))
+            self.notes_list.pack(fill=tk.X, expand=1)
+
+            note_frame = tk.Frame(paned_window)
+
+        paned_window.add(note_frame)
+
+        note_meta_frame = tk.Frame(note_frame)
         note_meta_frame.pack(side=tk.BOTTOM, fill=tk.X)
 
         pinned_label = tk.Label(note_meta_frame,text="Pinned")
         pinned_label.pack(side=tk.LEFT)
         self.pinned_checkbutton_var = tk.IntVar()
-        pinned_checkbutton = tk.Checkbutton(note_meta_frame, variable=self.pinned_checkbutton_var)
-        pinned_checkbutton.pack(side=tk.LEFT)
+        self.pinned_checkbutton = tk.Checkbutton(note_meta_frame, variable=self.pinned_checkbutton_var)
+        self.pinned_checkbutton.pack(side=tk.LEFT)
 
         tags_label = tk.Label(note_meta_frame, text="Tags")
         tags_label.pack(side=tk.LEFT)
@@ -926,8 +1034,10 @@ class View(utils.SubjectMixin):
             # change default font at runtime with:
             text.config(font=f)
 
+            # need expand=1 so that when user resizes window, text widget gets the extra space
             text.pack(fill=tk.BOTH, expand=1)
 
+
             #xscrollbar.config(command=text.xview)
             yscrollbar.config(command=text.yview)
 
@@ -935,7 +1045,7 @@ class View(utils.SubjectMixin):
 
 
         # setup user_text ###############################################
-        self.text_note = create_scrolled_text(right_frame)
+        self.text_note = create_scrolled_text(note_frame)
         self.fonts = self.notes_list.fonts + self.text_note.fonts
 
         # finish UI creation ###########################################
@@ -953,6 +1063,48 @@ class View(utils.SubjectMixin):
         """Handler for exit menu command and close window event.
         """
         self.notify_observers('close', None)
+
+    def clear_note_ui(self, silent=True):
+        """Called when no note has been selected.
+
+        Should give the user clear indication that no note has been selected,
+        hence no note editing actions can be taken.
+
+        @param silent: The default is not to fire any event handlers when
+        clearing the note.
+        @return:
+        """
+
+        # ascii art created with: http://patorjk.com/software/taag/
+
+        msg = """
+        No note currently selected.
+
+        Either select a note, or press Ctrl-N to create
+        a new note titled with the current search string,
+        or modify the search string.
+
+        .__   __. ____    ____ .______   ____    ____
+        |  \ |  | \   \  /   / |   _  \  \   \  /   /
+        |   \|  |  \   \/   /  |  |_)  |  \   \/   /
+        |  . `  |   \      /   |   ___/    \_    _/
+        |  |\   |    \    /    |  |          |  |
+        |__| \__|     \__/     | _|          |__|
+
+
+        """
+
+        if silent:
+            self.mute_note_data_changes()
+
+        self.text_note.delete(1.0, tk.END) # clear all
+        self.text_note.insert(1.0, msg)
+        self.tags_entry_var.set('')
+
+        self.statusbar.set_note_status('No note selected.')
+
+        if silent:
+            self.unmute_note_data_changes()
         
     def close(self):
         """Programmatically close application windows.
@@ -975,6 +1127,7 @@ class View(utils.SubjectMixin):
 
 
     def cmd_help_about(self):
+
         tkMessageBox.showinfo(
             'Help | About',
             'nvPY %s is copyright 2012 by Charl P. Botha '
@@ -1128,6 +1281,10 @@ class View(utils.SubjectMixin):
             webbrowser.open(link)
             
     def activate_search_string_highlights(self):
+        # no note selected, so no highlights.
+        if self.notes_list.selected_idx < 0:
+            return
+
         t = self.text_note
         
         # remove all existing tags
